@@ -60,16 +60,26 @@ def normalize_number(prettynumber):
 	>>> normalize_number("+012-(345)-678-90")
 	'+01234567890'
 	>>> normalize_number("1-(345)-678-9000")
-	'13456789000'
+	'+13456789000'
 	>>> normalize_number("+1-(345)-678-9000")
 	'+13456789000'
 	"""
 	uglynumber = re.sub('[^0-9+]', '', prettynumber)
 
+	if uglynumber.startswith("+"):
+		pass
+	elif uglynumber.startswith("1"):
+		uglynumber = "+"+uglynumber
+	elif 10 <= len(uglynumber):
+		assert uglynumber[0] not in ("+", "1")
+		uglynumber = "+1"+uglynumber
+	else:
+		pass
+
 	return uglynumber
 
 
-def _make_pretty_with_areacodde(phonenumber):
+def _make_pretty_with_areacode(phonenumber):
 	prettynumber = "(%s)" % (phonenumber[0:3], )
 	if 3 < len(phonenumber):
 		prettynumber += " %s" % (phonenumber[3:6], )
@@ -87,13 +97,9 @@ def _make_pretty_local(phonenumber):
 
 def _make_pretty_international(phonenumber):
 	prettynumber = phonenumber
-	if phonenumber.startswith("0"):
-		prettynumber = "+%s " % (phonenumber[0:3], )
-		if 3 < len(phonenumber):
-			prettynumber += _make_pretty_with_areacodde(phonenumber[3:])
 	if phonenumber.startswith("1"):
 		prettynumber = "1 "
-		prettynumber += _make_pretty_with_areacodde(phonenumber[1:])
+		prettynumber += _make_pretty_with_areacode(phonenumber[1:])
 	return prettynumber
 
 
@@ -137,10 +143,10 @@ def make_pretty(phonenumber):
 		prettynumber = _make_pretty_international(phonenumber[1:])
 		if not prettynumber.startswith("+"):
 			prettynumber = "+"+prettynumber
-	elif 8 < len(phonenumber) and phonenumber[0] in ("0", "1"):
+	elif 8 < len(phonenumber) and phonenumber[0] in ("1", ):
 		prettynumber = _make_pretty_international(phonenumber)
 	elif 7 < len(phonenumber):
-		prettynumber = _make_pretty_with_areacodde(phonenumber)
+		prettynumber = _make_pretty_with_areacode(phonenumber)
 	elif 3 < len(phonenumber):
 		prettynumber = _make_pretty_local(phonenumber)
 	else:
@@ -256,6 +262,7 @@ class SmsEntryWindow(object):
 
 		self._window = self._widgetTree.get_widget("smsWindow")
 		self._window = hildonize.hildonize_window(self._app, self._window)
+		self._window.set_title("SMS")
 		self._window.connect("delete-event", self._on_delete)
 		self._window.connect("key-press-event", self._on_key_press)
 		self._window.connect("window-state-event", self._on_window_state_change)
